import { AppSettingsValueRaw } from './app-settings-value-raw';
import { Identity } from './identity';
import { ModificationInfo } from './modification-info';
import { ResourceContext } from './resource-context';
/**
 * A settings object.
 */
export interface AppSettingsObject {
    /**
     * The ID of the settings object.
     */
    objectId: string;
    /**
     * A short summary of settings. This can contain Markdown and will be escaped accordingly.
     */
    summary?: string;
    /**
     * A searchable summary string of the setting value. Plain text without Markdown.
     */
    searchSummary?: string;
    /**
     * The version of the object for optimistic locking. You can use it to detect simultaneous modifications by different users.
     *
     * It is generated upon retrieval (GET requests). If set on update (PUT request) or deletion, the update/deletion will be allowed only if there wasn't any change between the retrieval and the update.
     */
    version: string;
    /**
     * The schema on which the object is based.
     */
    schemaId?: string;
    /**
     * The version of the schema on which the object is based.
     */
    schemaVersion?: string;
    /**
     * Modification information about the setting.
     */
    modificationInfo?: ModificationInfo;
    /**
     * The resource context, which contains additional permission information about the object.
     */
    resourceContext?: ResourceContext;
    /**
     * The value of the setting.
     *
     *  It defines the actual values of settings' parameters.
     *
     * The actual content depends on the object's schema.
     */
    value?: AppSettingsValueRaw;
    owner?: Identity;
}
