/// <reference types="node" />
import { Binary } from '@dynatrace-sdk/http-client';
export interface CreateDocumentBody {
    /**
     * The name of this document. This name doesn't need to be unique and is *not* used as identifier. Maximum length is 128 characters.
     */
    name: string;
    /**
     * The type of this document. This type is *not* the Content-Type of the document, but instead adds a user-defined semantic. Maximum length is 128 characters.
     */
    type: string;
    /**
     * Optional description of this document. Maximum length is 256 characters.
     */
    description?: string;
    /**
     * The binary content of this document. Its exact type is taken from the `Content-Type` header, which is thus mandatory.
     */
    content: Binary | Buffer | Blob | File;
    /**
     * An optional user-provided id, in addition to the system-provided id. The following constraints apply:
     *  - It must be unique in this environment
     *  - Allowed characters: `A-Z` `a-z` `0-9` `-`.
     *  - It must not be a UUID, however it can contain a UUID, so e.g. `my-e015739d-da78-4fe4-bef1-e95c2420bc25` is allowed, while `e015739d-da78-4fe4-bef1-e95c2420bc25` is not allowed.
     *  - Maximum length is 100 characters.
     */
    externalId?: string;
}
