/// <reference types="node" />
import { Binary } from '@dynatrace-sdk/http-client';
export interface UpdateDocumentBody {
    /**
     * The name of this document. This name doesn't need to be unique and is *not* used as identifier.
     *
     * Maximum length is 128 characters.
     * Optional - if not provided, no change happens.
     */
    name?: string;
    /**
     * The type of this document. This type is *not* the Content-Type of the document, but instead adds a user-defined semantic.
     *
     * Maximum length is 128 characters.
     * Optional - if not provided, no change happens.
     */
    type?: string;
    /**
     * Description of this document.
     *
     * Maximum length is 256 characters.
     * Optional - if not provided, no change happens.
     */
    description?: string;
    /**
     * The binary content of this document. Its exact type is taken from the `Content-Type` header, which is thus mandatory.
     * Optional - if not provided, no change happens.
     */
    content?: Binary | Buffer | Blob | File;
    /**
     * An optional user-provided description of the snapshot's content or the changes it introduced.
     *
     * This description gets ignored if the query-param `create-snapshot` is not set to true.
     *
     * Maximum length is 128 characters.
     */
    snapshotDescription?: string;
    /**
     * Whether this document should be public. Public documents can be read by every user of the environment.
     * This can only be changed by the document owner.
     * Optional - if not provided, no change happens.
     */
    isPrivate?: boolean;
}
