import { documentsClient } from '@dynatrace-sdk/client-document';
import { HookOptions } from './types/HookOptions';
/**
 * Provides the parameters for getDocument
 */
export type DocumentParams = Omit<Parameters<typeof documentsClient.getDocument>[0], 'abortSignal'>;
/**
 * Retrieve metadata and content for documents.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useDocument(params: DocumentParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-document").GetDocumentResponse | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-document").GetDocumentResponse>;
    cancel: () => void;
};
/**
 * Provides the parameters for getDocumentMetadata
 */
export type DocumentMetaDataParams = Omit<Parameters<typeof documentsClient.getDocumentMetadata>[0], 'abortSignal'>;
/**
 * Retrieve document metadata.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useDocumentMetaData(params: DocumentMetaDataParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-document").DocumentMetaData | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-document").DocumentMetaData>;
    cancel: () => void;
};
/**
 * Provides the parameters for listDocuments
 */
export type ListDocumentsParams = Omit<NonNullable<Parameters<typeof documentsClient.listDocuments>[0]>, 'abortSignal'>;
/**
 * List all documents accessible to you.
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useListDocuments(params: ListDocumentsParams | undefined, options?: HookOptions): {
    data: import("@dynatrace-sdk/client-document").DocumentList | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/client-document").DocumentList>;
    cancel: () => void;
};
/**
 * Provides the parameters for downloadDocumentContent
 */
export type DownloadDocumentParams = Omit<Parameters<typeof documentsClient.downloadDocumentContent>[0], 'abortSignal'>;
/**
 * Download document content
 * @param params Parameters for the client sdk call.
 * @param {HookOptions} [options={ autoFetch: true, autoFetchOnUpdate: true }] - Additional options for the react hook.
 */
export declare function useDownloadDocument(params: DownloadDocumentParams, options?: HookOptions): {
    data: import("@dynatrace-sdk/http-client").Binary | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isLoading: boolean;
    isSuccess: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
    refetch: (...args: string[]) => Promise<import("@dynatrace-sdk/http-client").Binary>;
    cancel: () => void;
};
/**
 * Provides the parameters for createDocument
 */
export type CreateDocumentBodyParams = Omit<Parameters<typeof documentsClient.createDocument>[0], 'abortSignal'>;
/**
 * Create a new document.
 */
export declare function useCreateDocument(): {
    execute: (params: CreateDocumentBodyParams) => Promise<void>;
    data: import("@dynatrace-sdk/client-document").DocumentMetaData | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for updateDocument
 */
export type UpdateDocumentParams = Omit<Parameters<typeof documentsClient.updateDocument>[0], 'abortSignal'>;
/**
 * Update metadata and content.
 */
export declare function useUpdateDocument(): {
    execute: (params: UpdateDocumentParams) => Promise<void>;
    data: import("@dynatrace-sdk/client-document").UpdateDocumentMetadata | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for updateDocumentMetadata
 */
export type UpdateDocumentMetadataParams = Omit<Parameters<typeof documentsClient.updateDocumentMetadata>[0], 'abortSignal'>;
/**
 * Update document metadata
 */
export declare function useUpdateDocumentMetadata(): {
    execute: (params: UpdateDocumentMetadataParams) => Promise<void>;
    data: import("@dynatrace-sdk/client-document").DocumentMetaData | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
/**
 * Provides the parameters for deleteDocument
 */
export type DeleteDocumentsParams = Omit<Parameters<typeof documentsClient.deleteDocument>[0], 'abortSignal'>;
/**
 * Delete the document
 */
export declare function useDeleteDocument(): {
    execute: (params: DeleteDocumentsParams) => Promise<void>;
    data: void | undefined;
    error: Error | undefined;
    errorDetails: import("@dynatrace-sdk/client-document").Error;
    isError: boolean;
    isSuccess: boolean;
    isLoading: boolean;
    status: import("./react-async-hook/react-async-hook").AsyncStateStatus;
};
